==> phpgroupware-0.9.16.005.tbz: www/data-dist/phpgroupware/phpsysinfo/includes/lang/tw.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: tw.php,v 1.1.2.1 2003/11/01 22:10:21 skwashd Exp $

$charset		= 'big5';

$text['title']          = 'tθT';

$text['vitals']         = 'tΥDnT';
$text['hostname']       = 'DW';
$text['ip']             = 'D~ IP';
$text['kversion']       = '֤ߪ';
$text['uptime']         = '}ɶ';
$text['users']          = 'uWϥΪ';
$text['loadavg']        = 't';

$text['hardware']       = 'wT';
$text['numcpu']         = 'Bzƶq';
$text['cpumodel']       = 'Model';
$text['mhz']            = 't';
$text['cache']          = '֨jp';
$text['bogomips']       = 't Bogomips';
$text['pci']            = 'PCI ]';
$text['ide']            = 'IDE ]';
$text['scsi']           = 'SCSI ]';

$text['netusage']       = 'ϥζq';
$text['device']         = ']';
$text['received']       = '';
$text['sent']           = 'eX';
$text['errors']         = '~/_';

$text['memusage']       = 'Oϥζq';
$text['phymem']         = 'O';
$text['swap']           = 'O(Ϻиm)';

$text['fs']             = 'wɮרt';
$text['mount']          = '|';
$text['partition']      = 'κϰ';

$text['percent']        = 'ϥζqʤ';
$text['type']           = 'A';
$text['free']           = 'ѾlŶ';
$text['used']           = 'wϥ';
$text['size']           = '`eq';
$text['totals']         = '`ϥζq';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'L';

$text['capacity']       = 'eq'; 

$text['template']       = 'd';
$text['language']       = 'y';
$text['submit']         = 'eX';
$text['created']        = 'ͥ';

$text['days']           = '';
$text['hours']          = 'p';
$text['minutes']        = '';
?>

==> phpgroupware-0.9.16.017.tbz: www/data-dist/phpgroupware/phpsysinfo/includes/lang/tw.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: tw.php 21052 2010-03-25 22:44:08Z Caeies $

$charset                = 'big5';

$text['title']          = 'tθT';

$text['vitals']         = 'tΥDnT';
$text['hostname']       = 'DW';
$text['ip']             = 'D~ IP';
$text['kversion']       = '֤ߪ';
$text['dversion']       = 'Distro Name';
$text['uptime']         = '}ɶ';
$text['users']          = 'uWϥΪ';
$text['loadavg']        = 't';

$text['hardware']       = 'wT';
$text['numcpu']         = 'Bzƶq';
$text['cpumodel']       = 'CPU';
$text['cpuspeed']       = 't';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = '֨jp';
$text['bogomips']       = 't Bogomips';

$text['pci']            = 'PCI ]';
$text['ide']            = 'IDE ]';
$text['scsi']           = 'SCSI ]';
$text['usb']            = 'USB ]';

$text['netusage']       = 'ϥζq';
$text['device']         = ']';
$text['received']       = '';
$text['sent']           = 'eX';
$text['errors']         = '~/_';

$text['memusage']       = 'Oϥζq';
$text['phymem']         = 'O';
$text['swap']           = 'O(Ϻиm)';

$text['fs']             = 'wɮרt';
$text['mount']          = '|';
$text['partition']      = 'κϰ';

$text['percent']        = 'ϥζqʤ';
$text['type']           = 'A';
$text['free']           = 'ѾlŶ';
$text['used']           = 'wϥ';
$text['size']           = '`eq';
$text['totals']         = '`ϥζq';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'L';

$text['capacity']       = 'eq';

$text['template']       = 'd';
$text['language']       = 'y';
$text['submit']         = 'eX';
$text['created']        = 'ͥ';
$text['locale']         = 'zh_TW.Big5';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = '';
$text['hours']          = 'p';
$text['minutes']        = '';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degreeC']        = '&deg;C';
$text['degreeF']        = '&deg;F';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= 'Kernel + applications';
$text['buffers']	= 'Buffers';
$text['cached']		= 'Cached';

$text['connections']    = 'Established Network Connections';
?>
